clearvars;
%% modelling of U-Th-Pb systematics for a spherical inclusion

%this code models:
    %204Pb-diffusion only
    %206Pb,207Pb,208Pb-duffision+production
    %235U,228U,232Th-decay only
    %either t-T path of your choice or that assumed by Dodson's equation

%the code is structured as follows
    %Inputs
        %physical dimensions of the model and physical constants
        %U-Th-Pb distribution
        %t-T path to model
    %Calculations
        %calculation of inital 235,238U, 232Th and 204,206,207,208Pb profiles
        %modelling of the t-T path
        %calculation of bulk-grain dates
    %Output
        %create output mat and txt files (the structure of the output txt file is described in this section)
        %create a summary figure

%important notes
    %207Pb-corrected dates are calculated correctrly only when they exceed 1 Ma
        
%% physical dimensions of the model and physical constants

%model resolution
Nr=571; %number of  nodes in r direction
LrIncl = 150; %inclusion radius
Lr = LrIncl/0.7; %radius of the model
dr = Lr/(Nr-1); %distance between the nodes in r
r=0:dr:Lr; %distance from the centre of the model

%physical constants used in the model
R = 8.3144598; %gas constant in J*mol^-1*K^-1
lambda238 = 4.91933E-18; %238U decay constant in sec^-1
lambda235 = 3.1221E-17; %235U decay constant in sec^-1
lambda232 = 1.56438E-18; %232Th decay constant sec^-1
presentU238U235=137.88125; %present-day ratio between the U isotopes
year=31556925.445; %year duration  in sec
KdPb=5;  %partiotion coefficient in a form Host/Inclusion

% diffusion properties of the inclusion
InclDPbr0 = 12700;  %frequency factor in micron^2*sec^-1
InclEactPbr = 228469.8063; %activation energy in J*mol^-1

% diffusion properties of the host-mineral
HostDPbr0 = 14200000; %frequency factor in micron^2*sec^-1
HostEactPbr = 305000/100; %activation energy in J*mol^-1





%generate necessary variables
Mineral = r*0; %indicator of which mineral is in the node (0 for Host and 1 for Inclusion)
MineralIntervals = r(1:end-1)*0; %indicator of which mineral is between the nodes (0 for Host and 1 for Inclusion)
Pb204 = r*0; Pb206 = r*0; Pb207 = r*0; Pb208 = r*0; U238  = r*0; U235  = r*0; Th232 = r*0; %concentrations
ratiosPb206Pb204=r*0; ratiosPb207Pb204=r*0; ratiosPb208Pb204=r*0; ratiosPb206U238=r*0; ratiosPb207U235=r*0; ratiosPb208Th232=r*0; %ratios
agesPb206U238=r*0; agesPb207U235=r*0; agesPb208Th232=r*0; agesPb207Pb206=r*0; %ages
DPbr     = r(1:end-1)*0; %diffusivity between the nodes
KdPbNodes=r*0+1; %Kd in the nodes
KdPbIntervals= r(1:end-1)*0+1; %Kd between the nodes
L=spalloc(Nr,Nr,((Nr-2)*3+3)); R204=zeros(Nr,1); R206=zeros(Nr,1); R207=zeros(Nr,1); R208=zeros(Nr,1);%allocate space for the matrices needed for the CN scheme

%% U-Th-Pb distribution

%define the boundaries of the inclusion
Mineral(r<=LrIncl)=1; %indicator of which mineral is in the node (0 for Host and 1 for Inclusion)
MineralIntervals(1:end)=Mineral(2:end); %indicator of which mineral is between the nodes (0 for Host and 1 for Inclusion)

%define the initial 204Pb concentrations in the inclusion and in the host
Pb204(r<=LrIncl)=0.1045;
Pb204(r>LrIncl)=0.5227;

%define the initial Pb isotopic composition
initialPb206Pb204=18.21; %206Pb/204Pb
initialPb207Pb204=16.03; %207Pb/204Pb
initialPb208Pb204=36.00; %208Pb/204Pb

%define initial 238U  concentrations
U238(r<=LrIncl*0.9)=10;
U238(r>LrIncl*0.9 & r<=LrIncl)=10;
U238(r>LrIncl)=0;

%define initial 238U  concentrations
Th232(r<=LrIncl)=50;
Th232(r>LrIncl)=0;

%% Create time-temperature path
%two options are available - t-T path assumed by Dodson's equation and custom t-T path
%use comment sign to deactivate one of the options

% %option 1 - t-T path assumed by Dodson's equation for a specified cooling rate
% CR=1; %specify the cooling rate in degrees per m.y. (at the closure temperature)
% dtinflections=0.02; %specify the time gap between any two points in the t-T path
% inflectionsCRlength=50000; %specify the number of points in the t-T path
% %12 lines below calculate the t-T path
% Tc=0; 
% while ( Tc < ((InclEactPbr/R)/(log( 55*R*(Tc+273)^2*InclDPbr0/LrIncl^2/InclEactPbr/CR*1000000*year  ) ) - 273  )  )
%       Tc=Tc+0.01;
% end
% kinflections=(1/(Tc+(-CR)/1000000)-1/(Tc-(-CR)/1000000))/(2/1000000);
% binflections=1/1000;
% timeinflections=0;
% for inflectionssteps=1:1:inflectionsCRlength
%     inflections(1,inflectionssteps)=timeinflections;
%     inflections(2,inflectionssteps)=1/(timeinflections*kinflections+binflections);
%     timeinflections=timeinflections+dtinflections;
% end

% %option 2 - custom t-T path
% inflections=[0  , 0.01,  40,  75, 170;...  %time in m.y. (0 - time of crystallisation)
%              800,  230, 230, 100,  0];  %Temperatures in Celcium degrees

%t-T path resolution
tTpointsperinterval=1; %integer that specifies the number of additional points between any two points in the "inflections" variable (calculated automatically by linear interpolation)





%calculate the t-T path that is actually used for modelling
sizeofinflections=size(inflections); % need to determine an interval t-T path within which dt and T are calculated
stepscounter=1; % counts number of iterations to write the newly obtained dt and T in a new column
tottime=0; % sums up all dt to det t-T path
T = 0; % Temperature Celcium degrees
for interval=1:1:(sizeofinflections(2)-1)
    if (inflections(1,interval+1)>inflections(1,interval))   
        k=(inflections(2,interval+1)-inflections(2,interval))/((inflections(1,interval+1)-inflections(1,interval))*1000000*year);
        b=inflections(2,interval)-k*inflections(1,interval)*1000000*year;
        stepscounter2=1;
        timedif=0;
        while (tottime<(inflections(1,interval+1)*1000000*year))
            dt=(inflections(1,interval+1)-inflections(1,interval))*1000000*year/tTpointsperinterval;

                if (k<=0)
                    T=(tottime+dt/2)*k+b;                
                else
                    T=(inflections(1,interval+1)*1000000*year-timedif-dt/2)*k+b;                
                end           

            if (k<=0)
                CoolingCurve(1,stepscounter)=dt;
                CoolingCurve(2,stepscounter)=T;
                CoolingCurve(3,stepscounter)=tottime/1000000/year;
                CoolingCurve(4,stepscounter)=inflections(1,sizeofinflections(2))-tottime/1000000/year;
                stepscounter=stepscounter+1;
            else
                HeatingInterval(1,stepscounter2)=dt;
                HeatingInterval(2,stepscounter2)=T;
                timedif=timedif+dt;
                HeatingInterval(3,stepscounter2)=timedif/1000000/year;
                stepscounter2=stepscounter2+1;
            end
            tottime=tottime+dt;
        end 

        % rewrite heating interval into cooling curve in the right order 
        if (k>0)
            stepscounteri=stepscounter;
            while (stepscounter <=(stepscounter2-2+stepscounteri) )
                CoolingCurve(1,stepscounter)=HeatingInterval(1,(stepscounter2-2+stepscounteri-stepscounter+1));
                CoolingCurve(2,stepscounter)=HeatingInterval(2,(stepscounter2-2+stepscounteri-stepscounter+1));
                CoolingCurve(3,stepscounter)=inflections(1,interval)+(HeatingInterval(3,(stepscounter2-1))-HeatingInterval(3,(stepscounter2-2+stepscounteri-stepscounter+1)));
                CoolingCurve(4,stepscounter)=inflections(1,sizeofinflections(2))-(inflections(1,interval)+(HeatingInterval(3,(stepscounter2-1))-HeatingInterval(3,(stepscounter2-2+stepscounteri-stepscounter+1))));
                stepscounter=stepscounter+1;
            end
            clearvars HeatingInterval;
        end
    else
    end
end
sizeofCoolingCurve=size(CoolingCurve);
Nt=sizeofCoolingCurve(2);
TimeSum=0;

%% diffusion/decay modelling

%preprocesseing (obtain missing variables, calclulate initial 235,238U and 232Th)
KdPbNodes(Mineral==1)=KdPb;
KdPbIntervals(MineralIntervals==1)=KdPb;
for i=1:1:Nr
    Pb206(i)=Pb204(i)*initialPb206Pb204;
    Pb207(i)=Pb204(i)*initialPb207Pb204;
    Pb208(i)=Pb204(i)*initialPb208Pb204;
    U235(i)=U238(i)/presentU238U235;
    U238(i)=U238(i)*exp(lambda238*(inflections(1,sizeofinflections(2))*1000000*year));
    U235(i)=U235(i)*exp(lambda235*(inflections(1,sizeofinflections(2))*1000000*year));
    Th232(i)=Th232(i)*exp(lambda232*(inflections(1,sizeofinflections(2))*1000000*year));
end

% diffusion calculation
for it=1:1:Nt
    T=CoolingCurve(2,it);
    dt=CoolingCurve(1,it);
    
    % Diffusivities update
    DPbr(MineralIntervals==1)=InclDPbr0 * exp(-(InclEactPbr)/R/(T+273));
    DPbr(MineralIntervals==0)=HostDPbr0 * exp(-(HostEactPbr)/R/(T+273));
        
    % Compose matrix
    for i=1:1:Nr
        
        % boundary conditions
        if (i==Nr)   % at r=max
            L(i,i)=1;
            
            R204(i,1)=Pb204(i);
            R206(i,1)=Pb206(i)+U238(i)*(1-exp(-lambda238*dt));
            R207(i,1)=Pb207(i)+U235(i)*(1-exp(-lambda235*dt));
            R208(i,1)=Pb208(i)+Th232(i)*(1-exp(-lambda232*dt));
                        
        elseif (i==1)  % at r=0
            CoefA=3*dt*DPbr(i)/(dr^2);
            CoefB=3*dt*DPbr(i)/(dr^2);
            
            L(i,i)=(1+CoefB);
            L(i,i+1)=-CoefA;
                        
            R204(i,1)=CoefA*Pb204(i+1)+(1-CoefB)*Pb204(i);
            R206(i,1)=CoefA*Pb206(i+1)+(1-CoefB)*Pb206(i)+U238(i)*(1-exp(-lambda238*dt));
            R207(i,1)=CoefA*Pb207(i+1)+(1-CoefB)*Pb207(i)+U235(i)*(1-exp(-lambda235*dt));
            R208(i,1)=CoefA*Pb208(i+1)+(1-CoefB)*Pb208(i)+Th232(i)*(1-exp(-lambda232*dt));
        
        %internal nodes
        else
            
            CoefA=dt*KdPbNodes(i+1)*((r(i)+r(i+1))/2)^2*DPbr(i)/2/(dr^2)/(r(i)^2)/KdPbIntervals(i);
            CoefB=dt*KdPbNodes(i)/2/(r(i)^2)/(dr^2)*(((r(i)+r(i-1))/2)^2*DPbr(i-1)/KdPbIntervals(i-1)  +     ((r(i)+r(i+1))/2)^2*DPbr(i)/KdPbIntervals(i) );
            CoefE=dt*KdPbNodes(i-1)*((r(i)+r(i-1))/2)^2*DPbr(i-1)/2/(dr^2)/(r(i)^2)/KdPbIntervals(i-1);
                        
            L(i,i-1)=-CoefE;
            L(i,i)=(1+CoefB);
            L(i,i+1)=-CoefA;
            
            R204(i,1)=CoefE*Pb204(i-1)+...
                (1-CoefB)*Pb204(i)+...
                   CoefA*Pb204(i+1);
            R206(i,1)=CoefE*Pb206(i-1)+...
                (1-CoefB)*Pb206(i)+...
                   CoefA*Pb206(i+1)+...
               U238(i)*(1-exp(-lambda238*dt));
            R207(i,1)=CoefE*Pb207(i-1)+...
                (1-CoefB)*Pb207(i)+...
                   CoefA*Pb207(i+1)+...
               U235(i)*(1-exp(-lambda235*dt));
            R208(i,1)=CoefE*Pb208(i-1)+...
                (1-CoefB)*Pb208(i)+...
                   CoefA*Pb208(i+1)+...
               Th232(i)*(1-exp(-lambda232*dt));
                       
        end
    end
    
    S204=L\R204;
    S206=L\R206;
    S207=L\R207;
    S208=L\R208;
        
    U238=U238.*exp(-lambda238*dt);
    U235=U235.*exp(-lambda235*dt);
    Th232=Th232.*exp(-lambda232*dt);
    
    Pb204=S204;
    Pb206=S206;
    Pb207=S207;
    Pb208=S208;
    
    TimeSum=TimeSum+dt/year/1000000;
end

%integrate isotope quantities and calculate in situ dates
InclSumPb204=0;
InclSumPb206=0;
InclSumPb207=0;
InclSumPb208=0;
InclSumU238=0;
InclSumU235=0;
InclSumTh232=0;

for i=1:1:Nr
        ratiosPb206Pb204(i)=Pb206(i)/Pb204(i);
        ratiosPb207Pb204(i)=Pb207(i)/Pb204(i);
        ratiosPb208Pb204(i)=Pb208(i)/Pb204(i);
        
        if (U238(i)>0)
            ratiosPb206U238(i)=Pb206(i)/U238(i);
            ratiosPb207U235(i)=Pb207(i)/U235(i);
            ratiosPb208Th232(i)=Pb208(i)/Th232(i);
                        
            agesPb206U238(i)=log((Pb206(i)/Pb204(i)-initialPb206Pb204)/(U238(i)/Pb204(i))+1)/lambda238/year/1000000;
            agesPb207U235(i)=log((Pb207(i)/Pb204(i)-initialPb207Pb204)/(U235(i)/Pb204(i))+1)/lambda235/year/1000000;
            agesPb208Th232(i)=log((Pb208(i)/Pb204(i)-initialPb208Pb204)/(Th232(i)/Pb204(i))+1)/lambda232/year/1000000;
        
            agesPb207Pb206(i)=1;
            
            while ( 0.0001 < sqrt((...
                    ( (Pb207(i)/Pb206(i)- initialPb207Pb204/initialPb206Pb204)/(U238(i)/Pb206(i)) ) * ...
                    ( 1/(exp(lambda238*year*1000000*agesPb207Pb206(i))-1) )+...
                    ( Pb207(i)/Pb206(i) -  U238(i)/Pb206(i)*( (Pb207(i)/Pb206(i)- initialPb207Pb204/initialPb206Pb204)/(U238(i)/Pb206(i)) ) )-...
                    ( exp(lambda235*year*1000000*agesPb207Pb206(i))-1 ) / (exp(lambda238*year*1000000*agesPb207Pb206(i))-1)/presentU238U235   )^2)   )
                
                agesPb207Pb206(i)=agesPb207Pb206(i)+ sqrt((...
                    ( (Pb207(i)/Pb206(i)- initialPb207Pb204/initialPb206Pb204)/(U238(i)/Pb206(i)) ) * ...
                    ( 1/(exp(lambda238*year*1000000*agesPb207Pb206(i))-1) )+...
                    ( Pb207(i)/Pb206(i) -  U238(i)/Pb206(i)*( (Pb207(i)/Pb206(i)- initialPb207Pb204/initialPb206Pb204)/(U238(i)/Pb206(i)) ) )-...
                    ( exp(lambda235*year*1000000*agesPb207Pb206(i))-1 ) / (exp(lambda238*year*1000000*agesPb207Pb206(i))-1)/presentU238U235   )^2)/2;
            end
        else
            ratiosPb206U238(i)=NaN;
            ratiosPb207U235(i)=NaN;
            ratiosPb208Th232(i)=NaN;
            
            agesPb206U238(i)=NaN;
            agesPb207U235(i)=NaN;
            agesPb208Th232(i)=NaN;
            agesPb207Pb206(i)=NaN;
        end
        if (Mineral(i)==1 && i==1)
            InclSumPb204=InclSumPb204+Pb204(i)*4/3*pi*(dr/2)^3;
            InclSumPb206=InclSumPb206+Pb206(i)*4/3*pi*(dr/2)^3;
            InclSumPb207=InclSumPb207+Pb207(i)*4/3*pi*(dr/2)^3;
            InclSumPb208=InclSumPb208+Pb208(i)*4/3*pi*(dr/2)^3;
            InclSumU238=InclSumU238+U238(i)*4/3*pi*(dr/2)^3;
            InclSumU235=InclSumU235+U235(i)*4/3*pi*(dr/2)^3;
            InclSumTh232=InclSumTh232+Th232(i)*4/3*pi*(dr/2)^3;
		elseif (Mineral(i)==1 && Mineral (i+1)==1 && i>1)
            InclSumPb204=InclSumPb204+Pb204(i)*pi*(4*r(i)^2*dr+dr^3/3);
            InclSumPb206=InclSumPb206+Pb206(i)*pi*(4*r(i)^2*dr+dr^3/3);
            InclSumPb207=InclSumPb207+Pb207(i)*pi*(4*r(i)^2*dr+dr^3/3);
            InclSumPb208=InclSumPb208+Pb208(i)*pi*(4*r(i)^2*dr+dr^3/3);
            InclSumU238=InclSumU238+U238(i)*pi*(4*r(i)^2*dr+dr^3/3);
            InclSumU235=InclSumU235+U235(i)*pi*(4*r(i)^2*dr+dr^3/3);
            InclSumTh232=InclSumTh232+Th232(i)*pi*(4*r(i)^2*dr+dr^3/3);
        end
end

WGagePb206U238=log((InclSumPb206/InclSumPb204-initialPb206Pb204)/(InclSumU238/InclSumPb204)+1)/lambda238/year/1000000;
WGagePb207U235=log((InclSumPb207/InclSumPb204-initialPb207Pb204)/(InclSumU235/InclSumPb204)+1)/lambda235/year/1000000;
WGagePb208Th232=log((InclSumPb208/InclSumPb204-initialPb208Pb204)/(InclSumTh232/InclSumPb204)+1)/lambda232/year/1000000;

WGagePb207Pb206=1;
while ( 0.0001 < sqrt((...
        ( (InclSumPb207/InclSumPb206- initialPb207Pb204/initialPb206Pb204)/(InclSumU238/InclSumPb206) ) * ...
        ( 1/(exp(lambda238*year*1000000*WGagePb207Pb206)-1) )+...
        ( InclSumPb207/InclSumPb206 -  InclSumU238/InclSumPb206*( (InclSumPb207/InclSumPb206- initialPb207Pb204/initialPb206Pb204)/(InclSumU238/InclSumPb206) ) )-...
        ( exp(lambda235*year*1000000*WGagePb207Pb206)-1 ) / (exp(lambda238*year*1000000*WGagePb207Pb206)-1)/presentU238U235   )^2)   )
                
        WGagePb207Pb206=WGagePb207Pb206+ sqrt((...
        ( (InclSumPb207/InclSumPb206- initialPb207Pb204/initialPb206Pb204)/(InclSumU238/InclSumPb206) ) * ...
        ( 1/(exp(lambda238*year*1000000*WGagePb207Pb206)-1) )+...
        ( InclSumPb207/InclSumPb206 -  InclSumU238/InclSumPb206*( (InclSumPb207/InclSumPb206- initialPb207Pb204/initialPb206Pb204)/(InclSumU238/InclSumPb206) ) )-...
        ( exp(lambda235*year*1000000*WGagePb207Pb206)-1 ) / (exp(lambda238*year*1000000*WGagePb207Pb206)-1)/presentU238U235   )^2)/2;
end

%calculate closure temperatures
if exist('CR','var')    
     for TcFinder=1:1:sizeofCoolingCurve(2)
         if (WGagePb206U238<=CoolingCurve(4,TcFinder) )
         Tc206238=CoolingCurve(2,TcFinder);
         end

         if (WGagePb207U235<=CoolingCurve(4,TcFinder) )
         Tc207235=CoolingCurve(2,TcFinder);
         end

         if (WGagePb207Pb206<=CoolingCurve(4,TcFinder) )
         Tc207206=CoolingCurve(2,TcFinder);
         end

         if (WGagePb208Th232<=CoolingCurve(4,TcFinder) )
         Tc208232=CoolingCurve(2,TcFinder);
         end    
     end
else
    Tc=NaN;
    Tc206238=NaN;
    Tc207235=NaN;
    Tc207206=NaN;
    Tc208232=NaN;
end

%% Output

%.mat file
save 'results.mat';

%.txt file
%go through the comments to see the structure of the output txt file 
%(lines in the output file appear in the same order)
for i=1:1:Nr
    if (i==1) %the first column in the output table
        Exportdatasheet(1,i)=LrIncl; %radius of the inclusion
        Exportdatasheet(2,i)=r(i); %coodrinate of any given node
        Exportdatasheet(3,i)=Pb204(i); %204Pb concentration in any given node
        Exportdatasheet(4,i)=Pb206(i); %206Pb concentration in any given node
        Exportdatasheet(5,i)=Pb207(i); %207Pb concentration in any given node
        Exportdatasheet(6,i)=Pb208(i); %208Pb concentration in any given node
        Exportdatasheet(7,i)=U238(i); %238U concentration in any given node
        Exportdatasheet(8,i)=U235(i); %235U concentration in any given node
        Exportdatasheet(9,i)=Th232(i); %232 Th concentration in any given node
        Exportdatasheet(10,i)=agesPb206U238(i); %206Pb/238U date in any given node
        Exportdatasheet(11,i)=agesPb207U235(i); %207Pb/235U date in any given node
        Exportdatasheet(12,i)=agesPb207Pb206(i); %207Pb-corrected date in any given node
        Exportdatasheet(13,i)=agesPb208Th232(i); %208Pb/232Th date in any given node
        Exportdatasheet(14,i)=WGagePb206U238; %bulk grain 206Pb/238U date
        Exportdatasheet(15,i)=WGagePb207U235; %bulk grain 207Pb/2358U date
        Exportdatasheet(16,i)=WGagePb207Pb206; %bulk grain 207Pb-corrected date
        Exportdatasheet(17,i)=WGagePb208Th232; %bulk grain 208Pb/232Th date
        Exportdatasheet(18,i)=Tc; %Dodson's closure temperature
        Exportdatasheet(19,i)=Tc206238; %closure temperature calculated using bulk grain 206Pb/238U date
        Exportdatasheet(20,i)=Tc207235; %closure temperature calculated using bulk grain 207Pb/235U date
        Exportdatasheet(21,i)=Tc207206; %closure temperature calculated using bulk grain 207Pb-corrected date
        Exportdatasheet(22,i)=Tc208232; %closure temperature calculated using bulk grain 208Pb/232Th date
    else %other columns in the output table
        Exportdatasheet(2,i)=r(i); %coodrinate of any given node
        Exportdatasheet(3,i)=Pb204(i); %204Pb concentration in any given node
        Exportdatasheet(4,i)=Pb206(i); %206Pb concentration in any given node
        Exportdatasheet(5,i)=Pb207(i); %207Pb concentration in any given node
        Exportdatasheet(6,i)=Pb208(i); %208Pb concentration in any given node
        Exportdatasheet(7,i)=U238(i); %238U concentration in any given node
        Exportdatasheet(8,i)=U235(i); %235U concentration in any given node
        Exportdatasheet(9,i)=Th232(i); %232 Th concentration in any given node
        Exportdatasheet(10,i)=agesPb206U238(i); %206Pb/238U date in any given node
        Exportdatasheet(11,i)=agesPb207U235(i); %207Pb/235U date in any given node
        Exportdatasheet(12,i)=agesPb207Pb206(i); %207Pb-corrected date in any given node
        Exportdatasheet(13,i)=agesPb208Th232(i); %208Pb/232Th date in any given node
    end
end
dlmwrite('results.txt', Exportdatasheet, 'delimiter', '\t');

%figures
figure(1);clf;

subplot(3,2,1);
plot(r,Pb204, ...
    r,Pb206, ...
    r,Pb207, ...
    r,Pb208,'LineWidth',2);
xlabel('r (\mum)');
ylabel('^2^0^8Pb (ppm)')
title('Pb concentrations');
legend('^2^0^4Pb','^2^0^6Pb','^2^0^7Pb','^2^0^8Pb');

subplot(3,2,2);
plot(r,U238, ...
    r,Th232,'LineWidth',2);
xlabel('r (\mum)');
ylabel('^2^3^8U (ppm)')
title('U, Th concentrations');
legend('^2^3^8U','^2^3^2Th');

subplot(3,2,3);
plot(-inflections(1,:)+(max(inflections(1,:))),inflections(2,:), 'LineWidth',2);
set(gca,'Xdir','reverse');
title('t-T path');
xlabel('Time (Ma)');
ylabel('Temperature (\circC)');

subplot(3,2,4);
plot(r,agesPb206U238, ...
    r,agesPb207U235, ...
    r,agesPb207Pb206, ...
    r,agesPb208Th232,'LineWidth',2);
ylim([min([min(agesPb206U238(1:round(LrIncl/dr)-1)) min(agesPb207U235(1:round(LrIncl/dr)-1)) min(agesPb207Pb206(1:round(LrIncl/dr)-1)) min(agesPb208Th232(1:round(LrIncl/dr)-1))])*0.9 max([max(agesPb206U238(1:round(LrIncl/dr)-1)) max(agesPb207U235(1:round(LrIncl/dr)-1)) max(agesPb207Pb206(1:round(LrIncl/dr)-1)) max(agesPb208Th232(1:round(LrIncl/dr)-1))])*1.1])
title('Age comparison along the R axis');
xlabel('r (\mum)');
ylabel('Date (Ma)');
legend('^2^0^6Pb/^2^3^8U date','^2^0^7Pb/^2^3^5U date','^2^0^7Pb-corrected date','^2^0^8Pb/^2^3^2Th date');

subplot(3,2,5);
plot(r,ratiosPb206Pb204, ...
    r,ratiosPb207Pb204, ...
    r,ratiosPb208Pb204, 'LineWidth',2);
title('Lead isotope ratios along the R axis');
xlabel('r (\mum)');
ylabel('ratio');
legend('^2^0^6Pb/^2^0^4Pb','^2^0^7Pb/^2^0^4Pb','^2^0^8Pb/^2^0^4Pb');

subplot(3,2,6);
plot(r,ratiosPb206U238, ...
    r,ratiosPb207U235, ...
    r,ratiosPb208Th232, 'LineWidth',2);
title('Daughter/parent ratios along the R axis');
xlabel('r (\mum)');
ylabel('ratio');
legend('^2^0^6Pb/^2^3^8U','^2^0^7Pb/^2^3^5U','^2^0^8Pb/^2^3^2Th');

print('output_profiles','-dpdf','-fillpage')

